@@ -49,12 +49,18 @@ KDEApplicationDebugSettingPage::KDEApplicationDebugSettingPage(QWidget *parent)
     mEnableDebug = new QPushButton(i18n("Enable All Debug"), this);
     mEnableDebug->setObjectName(QStringLiteral("selectall"));
     buttonLayout->addWidget(mEnableDebug);
-    connect(mEnableDebug, &QAbstractButton::clicked, this, &KDEApplicationDebugSettingPage::slotSelectAll);
+    connect(mEnableDebug, &QAbstractButton::clicked, this, &KDEApplicationDebugSettingPage::slotSelectAllDebug);
 
     mTurnOffDebug = new QPushButton(i18n("Turn Off Debug"), this);
     mTurnOffDebug->setObjectName(QStringLiteral("deselectall"));
     buttonLayout->addWidget(mTurnOffDebug);
-    connect(mTurnOffDebug, &QAbstractButton::clicked, this, &KDEApplicationDebugSettingPage::slotDeselectAll);
+    connect(mTurnOffDebug, &QAbstractButton::clicked, this, &KDEApplicationDebugSettingPage::slotDeselectAllDebug);
+
+    mTurnOffAllMessages = new QPushButton(i18n("Turn Off All Messages"), this);
+    mTurnOffAllMessages->setObjectName(QStringLiteral("deselectallmessage"));
+    buttonLayout->addWidget(mTurnOffAllMessages);
+    connect(mTurnOffAllMessages, &QAbstractButton::clicked, this, &KDEApplicationDebugSettingPage::slotDeselectAllMessages);
+
     mTreeListWidgetSearchLine->installEventFilter(this);
 }
 
@@ -74,16 +80,21 @@ bool KDEApplicationDebugSettingPage::eventFilter(QObject *obj, QEvent *event)
     return QWidget::eventFilter(obj, event);
 }
 
-void KDEApplicationDebugSettingPage::slotSelectAll()
+void KDEApplicationDebugSettingPage::slotSelectAllDebug()
 {
     mTreeListWidget->selectAllDebugCategories();
 }
 
-void KDEApplicationDebugSettingPage::slotDeselectAll()
+void KDEApplicationDebugSettingPage::slotDeselectAllDebug()
 {
     mTreeListWidget->deSelectAllDebugCategories();
 }
 
+void KDEApplicationDebugSettingPage::slotDeselectAllMessages()
+{
+    mTreeListWidget->deSelectAllMessagesCategories();
+}
+
 void KDEApplicationDebugSettingPage::fillList(const LoggingCategory::List &list)
 {
     mTreeListWidget->fillList(list);
